import asyncio
import logging
from typing import Optional, Dict, Any, List
from hyperliquid import HyperliquidSync, HyperliquidAsync
from config import Config

# Set up logging
logging.basicConfig(level=getattr(logging, Config.LOG_LEVEL))
logger = logging.getLogger(__name__)

class HyperliquidClient:
    """Wrapper class for Hyperliquid API client with enhanced functionality."""
    
    def __init__(self, use_testnet: bool = True):
        """
        Initialize the Hyperliquid client.
        
        Args:
            use_testnet: Whether to use testnet (default: True for safety)
        """
        self.use_testnet = use_testnet
        self.config = {
            'private_key': Config.HYPERLIQUID_PRIVATE_KEY,
            'testnet': use_testnet
        }
        
        # Initialize sync client
        self.sync_client = None
        self.async_client = None
        
        if Config.HYPERLIQUID_PRIVATE_KEY:
            try:
                self.sync_client = HyperliquidSync(self.config)
                logger.info(f"✅ Hyperliquid client initialized (testnet: {use_testnet})")
            except Exception as e:
                logger.error(f"❌ Failed to initialize Hyperliquid client: {e}")
        else:
            logger.warning("⚠️ No private key provided - client will have limited functionality")
    
    def get_balance(self) -> Optional[Dict[str, Any]]:
        """Get account balance."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            balance = self.sync_client.fetch_balance()
            logger.info("✅ Successfully fetched balance")
            return balance
        except Exception as e:
            logger.error(f"❌ Error fetching balance: {e}")
            return None
    
    def get_positions(self, symbol: Optional[str] = None) -> Optional[List[Dict[str, Any]]]:
        """Get current positions."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            positions = self.sync_client.fetch_positions([symbol] if symbol else None)
            logger.info(f"✅ Successfully fetched positions for {symbol or 'all symbols'}")
            return positions
        except Exception as e:
            logger.error(f"❌ Error fetching positions: {e}")
            return None
    
    def get_market_data(self, symbol: str) -> Optional[Dict[str, Any]]:
        """Get market data for a symbol."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            ticker = self.sync_client.fetch_ticker(symbol)
            orderbook = self.sync_client.fetch_order_book(symbol)
            
            market_data = {
                'ticker': ticker,
                'orderbook': orderbook,
                'symbol': symbol
            }
            
            logger.info(f"✅ Successfully fetched market data for {symbol}")
            return market_data
        except Exception as e:
            logger.error(f"❌ Error fetching market data for {symbol}: {e}")
            return None
    
    def place_limit_order(self, symbol: str, side: str, amount: float, price: float) -> Optional[Dict[str, Any]]:
        """
        Place a limit order.
        
        Args:
            symbol: Trading symbol (e.g., 'BTC/USDC:USDC')
            side: 'buy' or 'sell'
            amount: Order amount
            price: Order price
        """
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            order = self.sync_client.create_limit_order(symbol, side, amount, price)
            logger.info(f"✅ Successfully placed {side} limit order for {amount} {symbol} at ${price}")
            return order
        except Exception as e:
            logger.error(f"❌ Error placing limit order: {e}")
            return None
    
    def place_market_order(self, symbol: str, side: str, amount: float) -> Optional[Dict[str, Any]]:
        """
        Place a market order.
        
        Args:
            symbol: Trading symbol (e.g., 'BTC/USDC:USDC')
            side: 'buy' or 'sell'
            amount: Order amount
        """
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            order = self.sync_client.create_market_order(symbol, side, amount)
            logger.info(f"✅ Successfully placed {side} market order for {amount} {symbol}")
            return order
        except Exception as e:
            logger.error(f"❌ Error placing market order: {e}")
            return None
    
    def get_open_orders(self, symbol: Optional[str] = None) -> Optional[List[Dict[str, Any]]]:
        """Get open orders."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            orders = self.sync_client.fetch_open_orders(symbol)
            logger.info(f"✅ Successfully fetched open orders for {symbol or 'all symbols'}")
            return orders
        except Exception as e:
            logger.error(f"❌ Error fetching open orders: {e}")
            return None
    
    def cancel_order(self, order_id: str, symbol: str) -> bool:
        """Cancel an order."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return False
            
            result = self.sync_client.cancel_order(order_id, symbol)
            logger.info(f"✅ Successfully cancelled order {order_id}")
            return True
        except Exception as e:
            logger.error(f"❌ Error cancelling order {order_id}: {e}")
            return False
    
    def get_recent_trades(self, symbol: str, limit: int = 10) -> Optional[List[Dict[str, Any]]]:
        """Get recent trades for a symbol."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            trades = self.sync_client.fetch_trades(symbol, limit=limit)
            logger.info(f"✅ Successfully fetched {len(trades)} recent trades for {symbol}")
            return trades
        except Exception as e:
            logger.error(f"❌ Error fetching recent trades for {symbol}: {e}")
            return None
    
    def get_trading_fee(self, symbol: str) -> Optional[Dict[str, Any]]:
        """Get trading fee for a symbol."""
        try:
            if not self.sync_client:
                logger.error("❌ Client not initialized")
                return None
            
            fee = self.sync_client.fetch_trading_fee(symbol)
            logger.info(f"✅ Successfully fetched trading fee for {symbol}")
            return fee
        except Exception as e:
            logger.error(f"❌ Error fetching trading fee for {symbol}: {e}")
            return None 